@@ -4,13 +4,15 @@ from subprocess import PIPE, Popen
 class bash(object):
     "This is lower class because it is intended to be used as a method."
 
-    def __init__(self, cmd):
+    def __init__(self, cmd, env=None):
         self.p = None
         self.stdout = None
-        self.bash(cmd)
+        self.bash(cmd, env)
 
-    def bash(self, cmd):
-        self.p = Popen(cmd, shell=True, stdout=PIPE, stdin=PIPE, stderr=PIPE)
+    def bash(self, cmd, env=None):
+        self.p = Popen(
+            cmd, shell=True, stdout=PIPE, stdin=PIPE, stderr=PIPE, env=env
+        )
         self.stdout, self.stderr = self.p.communicate(input=self.stdout)
         self.code = self.p.returncode
         return self
